==> Acme-MetaSyntactic-0.14.tar.gz: Acme-MetaSyntactic-0.14/lib/Acme/MetaSyntactic/donmartin.pm <==
package Acme::MetaSyntactic::donmartin;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::donmartin - The Don Martin theme

=head1 DESCRIPTION

The sound effects from Don Martin's comics.
The comprehensive list is found here:
L<http://www.collectmad.com/madcoversite/dmd-alphabetical.html>

=head1 CONTRIBUTOR

Vahe Sarkissian.

Introduced in version 0.03, published on January 14, 2005.

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
aaaagh aaak aaeefwofaaee aagh aahht aaht aak aarh ack aeek agh ahh ahh
ahhh ahhh_glukle ahhhhhhhhhh ahweeeeee_ak ak aling aooga aoooga applaud
araragh arargh arg argh argle arrargh arrarghnnarrgh arrargle arrgh awk
bahoo bak bam bam_bam bang bap bap_krak barf barramm bash b_b_b_borfft
bbblplast bbfrprafpghpp bbllbbllbbllbbllbbll beaugh beedoop beeyoop
bing bizzzt blam blamp blap blapple blatch bleeble bleegh bleep blib
blib_blib blidit blif blink blink bliomp blit blobble bloit blonk bloof
bloom bloombloom bloooot bloop blop blorf blorp blort blub bluka blut
boil bong boom booma booma_roomba boomer_room boong bplflt braghk brak
brap bravo brbbrbbring breebeep breedeet breep_breep breet breet_breet
bring brnngt broodoot broom broot brrrapp brrrnng bump bur_rp bwaughk
bweep bzownt bzznnt bzzownt bzzt bzzz bzzzt cak caw caw_caw_caw cha_gonk
chaka chaklak chakunk chakunk_ding_rip cheeomp cheep chika chika_chunk
chimp chip chirp chk chomp chompity_chomp chomple chonk chook chop
chop_chop chuckle chuga chuh chukkunk_clunk chunk chunka chunk_kashink
clack claka clang clank clap clap_clap clatta clatter clatter_clatter
click clik clik clik clik_clik_clik_clik clink clip_clap cloink clomp
clonk cook crackle crash crugazunch crunch crunchle daba dabwak da_flaf
dak dakdik dakka dakkadak dakkitydak dang dapada dapadda deebe deep dig
dik dikka dimpah din ding dingalina dingalinga dink dink_dink_dink_dink
dipada dipadda dit dit_clunk doink doip doip doit dokka domp dong
don_t dooba doobada doobadoobadooba doodle doom dooma doomp doonk doont
dooot doop doot dootbweet dripple droot dubba dugga durp eat ecch eck
eckeck eeaheeaheeaheeaheeah eech eeeaaagh eeeeeeeeeeeeeeeee eeeeeooow
etc faba fabadap faglork fagroon fagrooosh fagwasshhhh fagwoosh fak
fap fapadda faroolana farrappght fashklork fashunk fat fazzat ferrap
ferrip few ffffoooooooo fffpfwrap fffrrraapft ffpghftp fiddit fidip_fidip
fiff_frrep fink fip fip_fip fit fitz fitzrower fizzazzit fizzitz flabadap
fladat fladip flaf flaffliff flak flap flapf fleedle flibadip flif flif
fliff fliff flifflaff fliffle fliffle flik flik fling flink flip flit
flizaff floba_dap flof flok floof floof floofity floom floon floot
flop floploploplop florf flork flot fluk flut fomp_dabomp foof foom
foomp foon foop foosh foosht foowoom fop fowm fpfworpft frit froom
frugga fsssh fump funk funkada fursh furshglurk fush fushshklork fut
fwabadap fwach fwaddapp fwak fwam fwap fwapada fwask fwee fweee fweeee
fweeeee fweeeeeeeee fween fweep fwiffffff fwip fwip fwip fwipada fwisk
fwisk fwiskitty fwit fwit_thhat fwizz fwizzach fwizzap fwizzish fwof
fwoof fwoosh fwooshsh fwop fwump fxlgxtlkfxg gaah gack gadaff gadang
gadiff_gadiff gadink gadoing gadong gadoon gaflor gahak gahoff gahork gak
galink galoon galooom gamop gaplonk gaplork gark garoof garrargh garrgh
garunk gashklitz gashklitzka ga_shklurtz gashkutzga gashlikt ga_shloip
gashook gashplutzga gaskrooch gasmatch gasmitch gasp gasp gasploosh
ga_splortch gasplush ga_wiz gazap gazikka gazoont gazownt geeen geen ghomp
gigazing gikkadik ging ging gishklork gishklurk gladink glakkle glangadang
glank glap glargle glawk gleep gleet_gleet glik glika_glika glikle glink
glink glip glish glit glitch glit_glikity gloing gloip glomp glong glont
gloochle gloodle glook gloop gloople gloot_gloot glorgle glork glorkle
glorp glort gloydoip glug gluk glukkle glukkle_gluk glunk glup glurgle
glurk glurkle glut glutch going gonk googlooom gooma_doom goosh gorshle
goyng grak grasp grawk greedle_greedle gring groink groom groon growr
growrrooom growwwwmmm grrm grrown grrr grrrrrr grunch gukguk gurgle gurn
gush guwk gwap gyaaught ha haah hac hak hakkle har hee_de_hee_hee heh
help hic hic hit hmmmm hm_m_m_m ho ho_hum honk hooray hoot huff huffa
huffle_puffle hush hushle ing inkle_klink jugarum ka kaboff ka_bong
kaboomm kachaah kachonk kachoo kachugh kachunk kachunka kachunk_kachunk
kachunk_kachunka kadoonk kahak kaheeee kahikf kaka_splak kakkakkakak
kakroosh kalloon kaloong kapf kaplak_kak kaplam kapoooshshish karrak
kash kashook kashpritza katoof katoong katoonk katy_did katy_didn_t kawk
kazak kazash kazik kazop kchgghck k_chook kerackk kik kikatik king kipf
kiss kittoong kkchk kkkkkkkkkkkk kkksh kkkssh kladwak klak klak_klak
klakkle klang klank klik klik klik_chikaklak klik_klik klik_klik_chaklik
klik_klik_klik klikrunk klik_sproing kling klingdinggoon klink klink
klinkadink kloink klomp klong klonk kloobada kloon kloong kloonk klooonn
klop kluk klumble klump klunk klupada knock koff kookook koong kopf
krak krakkle krakle krarkle krash kreek kridit_kridit krik krik_krikit
krugazunch krunch krunchle ksshfwoom ksssh kuk kwapp kweee kweek kwoip
kwong kwonk kwop laflatch leddle m mabbit mamp map_map mcpwaf mimpah mmmmm
mmmmmm mmmmmmmm mmmp mmm_shlurk mmp mmph mop mowm muffle nnyeeownnt nok
not_a_sound oggock ogh onnnnnghk oof ooga ooh oomp oonk oont oooh oookk
ooooooiiiiiiyyyyy oot padap paf pak pam pat patwang patweeee pblrblpsft
pffft_frack pflap phelop phlakffa phoom phoon phooo phwam pik ping ping
pink pitooie pittoo pittooie pittooie pittween pittwoon plablablablab
plablablablabl plaf plak plam plap plapf plif plink plipple plobble ploip
ploip plonk ploobadoof ploof ploom ploomploomploom ploop ploosh plop plorf
plork plortch pluf plunk plurp poffisss poing poing poing poink poink
poink poit poit poit pok poong pop pop___sproing_ging pow prawk psssh
pssssh pucka puff puff puffa pull putt pwadak pwam pween pwof pwoing pwok
pwompf quack quack_quack quiet qwack rah_ooom rattle rawgh rip ripf ror
rowm rowr rrip rrroooom rrrrr rrrrreerrr rrrrrr rumble rumboom_blooma
sazzikk schklurt schlap schlep schlip schlit schloop schloot scrape
screeeezt shabamp shak sha_pap shash shashwik shazzatz shhh shhhsk
shiffle shif_shaf shik shika shika_shika shk shkalink shkaloink shklakle
shklazitch shklik shklik shkliksa shklink shklitza shklitza shklizich
shklizortch shklizzitz shklizzortch shkloort shklop shklorbbadorp
shklorp shklunk shklurch shklurk shkwitz shlak shlik shlikle shlipp
shlook shloop shlork shlorp shlurk shlurp shmuzorft shnikkle shnip
shnorkle shompah_bombah shooga shook shooka shooo shossh shpikkle
shpishle shplep shpliple shploip shpooosh shpork shtik shtoink shtork
shuffle shuka shusshh shwik shwika silence sit sittzle sitz sizzle
sizzotz skapasch skaplunch skaproing skazeech skazooch sklazoncho
sklerch sklik sklishitty sklishk sklitch sklizzorch skloosh sklop sklork
sklorsh sklortch skloshitty skluk sklukle sklurk sklush skniffle sknikle
sknitch sknosh skrak skrakit skrawk skrazatz skrazitz skreech skreee
skreeee skreeeee skreeeeee skreeeeeeek skreeeeek skreeeek skreeek
skreek skreekle skreeyeeek skreeyeeyeeyeeyeek skribble skrich skricha
skrink skritch skroik skroinch skronch skronk skroom skroook skrotch
skrunch skruncha skwa_ba_dap skwako skwappo skweek skwik skwonk slapth
slice slice slobble sloople slotch slurk slurp smack smak smash smek
snap snat snif sniff sniffle snikker snip snip snork snuffle sob spa
spa_dow spaloosh spamamp spamp spap spash spashle spatz spazat spazoosh
spitz spladish_spladish spladunk splak spla_map splap splapidy_splip
splapple splash splat splatch splazatch splazitch splazoosh splesh splish
splishidy_splash splishidy_splashidy splishle splitch sploit sploosh
splop splork splorp splorple splort splosh sploydoing splurp spmam spmamp
spmap spoof spoosh spoosht spop spopple sprat sprazot spritsits spritz
sprizawitz sprizzitz sproing sproing sproingachonk sproingdoink sproink
sprop sprowmmm spukkonk spush sput sputz sputz_spitza spwako spwang spwap
spwappo spwat ssat sslit ssssssss sssssssst sssst stamp stealth stoink
stoof stoong stoopft stroinggoink sut swap swat swif swipadda swish swit
swit_plop swit_plop swit_swit swizap swizzak swizzat_swat swoosh sworf tak
takka tap tap tap_tap_tap ta_tagak tattatattat tear teeoo tffp thaff thak
thap thaploof thhhht thhhut thhlorp thikoosh thiz thlbbadup thlik thlip
thloop thluck thlup thoip thoipoing thomp thoo thoof_foing thoom thoomp
thoonoonn thooo thop thork thot thubalup thud thugawunk thuk thump thunck
thurch thuthhhh thwa_dap thwak thwap thwat thwip thwip thwit thwizzik
thwock thwok thwop thwuk tik tika tika_tika tikatik_chirp tikka tikkak
tik_tik tik_tika ting ting ting_aling tingalinga tink tip_tippity toing
tok tong tonk tood toodle toof toomp toon toong toonk tooong tooooo
toowit toowoo tromp trump tubba tweedle tweee tween twok twong twop
twoyyoyyoing tzing tzong tzoong tzwang ugh uk ulp umble umpf umph unklik
urp urrsssh ursshhh uuuuurp varoom varroom voofen voom voomarooma vow vowm
vown vreen vroom vroom_spak vroon vrooon vwoo waak wak walk wam wamp wap
wawkle wee weeeeeee weeeoooo weeeoooowee weeeooooweeeooo weeeoooweeeooowee
weeoooeeeooo weeoooo weeooweeeoooo weeooweeoooo whak wham whap wheeah whir
whir whirr whisk whomp whoooooooo whoosh wink winkity wink_wink wiz wong
wonk wooosh woopwoopwoop wunk wunkada xmng yaach yaah yaaugh yaggak yahhah
yak yarg yarg yargh yea yeech ying yippee yip_yip yip_yip_yip yowyowyow
yug yuk yukkle zachitty zak zap zat zazik zazzik zeem zgluk zich zidit
zik zika_zika zikka zikkik zik_zik zikzikzik zikzikzikzikzikzik zingo
zip zit zit_sreek zit_zat_zat zit_zit_zit zitzizizizzzzzz ziz ziz ziz
zizazik zizzak zlitz zock zooka zooo zoot zot zowm zownt zunch zweech
zween zweet zwit zwit_sproing zwot zzip zzt_chomp zzt_znik zzz zzzz
zzzzoownt zzzzz zzzzzz zzzzzzz zzzzzzzz zzzzzzzzz zzzzzzzzzzz

==> Acme-MetaSyntactic-0.51.tar.gz: Acme-MetaSyntactic-0.51/lib/Acme/MetaSyntactic/donmartin.pm <==
package Acme::MetaSyntactic::donmartin;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::donmartin - The Don Martin theme

=head1 DESCRIPTION

The sound effects from Don Martin's comics.
The comprehensive list is found here:
L<http://www.collectmad.com/madcoversite/dmd-alphabetical.html>

=head1 CONTRIBUTOR

Vahe Sarkissian.

Introduced in version 0.03, published on January 14, 2005.

Duplicates removed in version 0.15, published on March 28, 2005.

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
aaaagh aaak aaeefwofaaee aagh aahht aaht aak aarh ack aeek agh ahh
ahhh ahhh_glukle ahhhhhhhhhh ahweeeeee_ak ak aling aooga aoooga applaud
araragh arargh arg argh argle arrargh arrarghnnarrgh arrargle arrgh awk
bahoo bak bam bam_bam bang bap bap_krak barf barramm bash b_b_b_borfft
bbblplast bbfrprafpghpp bbllbbllbbllbbllbbll beaugh beedoop beeyoop
bing bizzzt blam blamp blap blapple blatch bleeble bleegh bleep blib
blib_blib blidit blif blink bliomp blit blobble bloit blonk bloof
bloom bloombloom bloooot bloop blop blorf blorp blort blub bluka blut
boil bong boom booma booma_roomba boomer_room boong bplflt braghk brak
brap bravo brbbrbbring breebeep breedeet breep_breep breet breet_breet
bring brnngt broodoot broom broot brrrapp brrrnng bump bur_rp bwaughk
bweep bzownt bzznnt bzzownt bzzt bzzz bzzzt cak caw caw_caw_caw cha_gonk
chaka chaklak chakunk chakunk_ding_rip cheeomp cheep chika chika_chunk
chimp chip chirp chk chomp chompity_chomp chomple chonk chook chop
chop_chop chuckle chuga chuh chukkunk_clunk chunk chunka chunk_kashink
clack claka clang clank clap clap_clap clatta clatter clatter_clatter
click clik clik_clik_clik_clik clink clip_clap cloink clomp
clonk cook crackle crash crugazunch crunch crunchle daba dabwak da_flaf
dak dakdik dakka dakkadak dakkitydak dang dapada dapadda deebe deep dig
dik dikka dimpah din ding dingalina dingalinga dink dink_dink_dink_dink
dipada dipadda dit dit_clunk doink doip doit dokka domp dong
don_t dooba doobada doobadoobadooba doodle doom dooma doomp doonk doont
dooot doop doot dootbweet dripple droot dubba dugga durp eat ecch eck
eckeck eeaheeaheeaheeaheeah eech eeeaaagh eeeeeeeeeeeeeeeee eeeeeooow
etc faba fabadap faglork fagroon fagrooosh fagwasshhhh fagwoosh fak
fap fapadda faroolana farrappght fashklork fashunk fat fazzat ferrap
ferrip few ffffoooooooo fffpfwrap fffrrraapft ffpghftp fiddit fidip_fidip
fiff_frrep fink fip fip_fip fit fitz fitzrower fizzazzit fizzitz flabadap
fladat fladip flaf flaffliff flak flap flapf fleedle flibadip flif
fliff flifflaff fliffle flik fling flink flip flit
flizaff floba_dap flof flok floof floofity floom floon floot
flop floploploplop florf flork flot fluk flut fomp_dabomp foof foom
foomp foon foop foosh foosht foowoom fop fowm fpfworpft frit froom
frugga fsssh fump funk funkada fursh furshglurk fush fushshklork fut
fwabadap fwach fwaddapp fwak fwam fwap fwapada fwask fwee fweee fweeee
fweeeee fweeeeeeeee fween fweep fwiffffff fwip fwipada fwisk
fwiskitty fwit fwit_thhat fwizz fwizzach fwizzap fwizzish fwof
fwoof fwoosh fwooshsh fwop fwump fxlgxtlkfxg gaah gack gadaff gadang
gadiff_gadiff gadink gadoing gadong gadoon gaflor gahak gahoff gahork gak
galink galoon galooom gamop gaplonk gaplork gark garoof garrargh garrgh
garunk gashklitz gashklitzka ga_shklurtz gashkutzga gashlikt ga_shloip
gashook gashplutzga gaskrooch gasmatch gasmitch gasp gasploosh
ga_splortch gasplush ga_wiz gazap gazikka gazoont gazownt geeen geen ghomp
gigazing gikkadik ging gishklork gishklurk gladink glakkle glangadang
glank glap glargle glawk gleep gleet_gleet glik glika_glika glikle glink
glip glish glit glitch glit_glikity gloing gloip glomp glong glont
gloochle gloodle glook gloop gloople gloot_gloot glorgle glork glorkle
glorp glort gloydoip glug gluk glukkle glukkle_gluk glunk glup glurgle
glurk glurkle glut glutch going gonk googlooom gooma_doom goosh gorshle
goyng grak grasp grawk greedle_greedle gring groink groom groon growr
growrrooom growwwwmmm grrm grrown grrr grrrrrr grunch gukguk gurgle gurn
gush guwk gwap gyaaught ha haah hac hak hakkle har hee_de_hee_hee heh
help hic hit hmmmm hm_m_m_m ho ho_hum honk hooray hoot huff huffa
huffle_puffle hush hushle ing inkle_klink jugarum ka kaboff ka_bong
kaboomm kachaah kachonk kachoo kachugh kachunk kachunka kachunk_kachunk
kachunk_kachunka kadoonk kahak kaheeee kahikf kaka_splak kakkakkakak
kakroosh kalloon kaloong kapf kaplak_kak kaplam kapoooshshish karrak
kash kashook kashpritza katoof katoong katoonk katy_did katy_didn_t kawk
kazak kazash kazik kazop kchgghck k_chook kerackk kik kikatik king kipf
kiss kittoong kkchk kkkkkkkkkkkk kkksh kkkssh kladwak klak klak_klak
klakkle klang klank klik klik_chikaklak klik_klik klik_klik_chaklik
klik_klik_klik klikrunk klik_sproing kling klingdinggoon klink
klinkadink kloink klomp klong klonk kloobada kloon kloong kloonk klooonn
klop kluk klumble klump klunk klupada knock koff kookook koong kopf
krak krakkle krakle krarkle krash kreek kridit_kridit krik krik_krikit
krugazunch krunch krunchle ksshfwoom ksssh kuk kwapp kweee kweek kwoip
kwong kwonk kwop laflatch leddle m mabbit mamp map_map mcpwaf mimpah mmmmm
mmmmmm mmmmmmmm mmmp mmm_shlurk mmp mmph mop mowm muffle nnyeeownnt nok
not_a_sound oggock ogh onnnnnghk oof ooga ooh oomp oonk oont oooh oookk
ooooooiiiiiiyyyyy oot padap paf pak pam pat patwang patweeee pblrblpsft
pffft_frack pflap phelop phlakffa phoom phoon phooo phwam pik ping
pink pitooie pittoo pittooie pittween pittwoon plablablablab
plablablablabl plaf plak plam plap plapf plif plink plipple plobble ploip
plonk ploobadoof ploof ploom ploomploomploom ploop ploosh plop plorf
plork plortch pluf plunk plurp poffisss poing poink
poit pok poong pop pop___sproing_ging pow prawk psssh
pssssh pucka puff puffa pull putt pwadak pwam pween pwof pwoing pwok
pwompf quack quack_quack quiet qwack rah_ooom rattle rawgh rip ripf ror
rowm rowr rrip rrroooom rrrrr rrrrreerrr rrrrrr rumble rumboom_blooma
sazzikk schklurt schlap schlep schlip schlit schloop schloot scrape
screeeezt shabamp shak sha_pap shash shashwik shazzatz shhh shhhsk
shiffle shif_shaf shik shika shika_shika shk shkalink shkaloink shklakle
shklazitch shklik shkliksa shklink shklitza shklizich
shklizortch shklizzitz shklizzortch shkloort shklop shklorbbadorp
shklorp shklunk shklurch shklurk shkwitz shlak shlik shlikle shlipp
shlook shloop shlork shlorp shlurk shlurp shmuzorft shnikkle shnip
shnorkle shompah_bombah shooga shook shooka shooo shossh shpikkle
shpishle shplep shpliple shploip shpooosh shpork shtik shtoink shtork
shuffle shuka shusshh shwik shwika silence sit sittzle sitz sizzle
sizzotz skapasch skaplunch skaproing skazeech skazooch sklazoncho
sklerch sklik sklishitty sklishk sklitch sklizzorch skloosh sklop sklork
sklorsh sklortch skloshitty skluk sklukle sklurk sklush skniffle sknikle
sknitch sknosh skrak skrakit skrawk skrazatz skrazitz skreech skreee
skreeee skreeeee skreeeeee skreeeeeeek skreeeeek skreeeek skreeek
skreek skreekle skreeyeeek skreeyeeyeeyeeyeek skribble skrich skricha
skrink skritch skroik skroinch skronch skronk skroom skroook skrotch
skrunch skruncha skwa_ba_dap skwako skwappo skweek skwik skwonk slapth
slice slobble sloople slotch slurk slurp smack smak smash smek
snap snat snif sniff sniffle snikker snip snork snuffle sob spa
spa_dow spaloosh spamamp spamp spap spash spashle spatz spazat spazoosh
spitz spladish_spladish spladunk splak spla_map splap splapidy_splip
splapple splash splat splatch splazatch splazitch splazoosh splesh splish
splishidy_splash splishidy_splashidy splishle splitch sploit sploosh
splop splork splorp splorple splort splosh sploydoing splurp spmam spmamp
spmap spoof spoosh spoosht spop spopple sprat sprazot spritsits spritz
sprizawitz sprizzitz sproing sproingachonk sproingdoink sproink
sprop sprowmmm spukkonk spush sput sputz sputz_spitza spwako spwang spwap
spwappo spwat ssat sslit ssssssss sssssssst sssst stamp stealth stoink
stoof stoong stoopft stroinggoink sut swap swat swif swipadda swish swit
swit_plop swit_swit swizap swizzak swizzat_swat swoosh sworf tak
takka tap tap_tap_tap ta_tagak tattatattat tear teeoo tffp thaff thak
thap thaploof thhhht thhhut thhlorp thikoosh thiz thlbbadup thlik thlip
thloop thluck thlup thoip thoipoing thomp thoo thoof_foing thoom thoomp
thoonoonn thooo thop thork thot thubalup thud thugawunk thuk thump thunck
thurch thuthhhh thwa_dap thwak thwap thwat thwip thwit thwizzik
thwock thwok thwop thwuk tik tika tika_tika tikatik_chirp tikka tikkak
tik_tik tik_tika ting ting_aling tingalinga tink tip_tippity toing
tok tong tonk tood toodle toof toomp toon toong toonk tooong tooooo
toowit toowoo tromp trump tubba tweedle tweee tween twok twong twop
twoyyoyyoing tzing tzong tzoong tzwang ugh uk ulp umble umpf umph unklik
urp urrsssh ursshhh uuuuurp varoom varroom voofen voom voomarooma vow vowm
vown vreen vroom vroom_spak vroon vrooon vwoo waak wak walk wam wamp wap
wawkle wee weeeeeee weeeoooo weeeoooowee weeeooooweeeooo weeeoooweeeooowee
weeoooeeeooo weeoooo weeooweeeoooo weeooweeoooo whak wham whap wheeah whir
whirr whisk whomp whoooooooo whoosh wink winkity wink_wink wiz wong
wonk wooosh woopwoopwoop wunk wunkada xmng yaach yaah yaaugh yaggak yahhah
yak yarg yargh yea yeech ying yippee yip_yip yip_yip_yip yowyowyow
yug yuk yukkle zachitty zak zap zat zazik zazzik zeem zgluk zich zidit
zik zika_zika zikka zikkik zik_zik zikzikzik zikzikzikzikzikzik zingo
zip zit zit_sreek zit_zat_zat zit_zit_zit zitzizizizzzzzz ziz
zizazik zizzak zlitz zock zooka zooo zoot zot zowm zownt zunch zweech
zween zweet zwit zwit_sproing zwot zzip zzt_chomp zzt_znik zzz zzzz
zzzzoownt zzzzz zzzzzz zzzzzzz zzzzzzzz zzzzzzzzz zzzzzzzzzzz
